==> xml-path-1.8.1-sources.jar: com/jayway/restassured/internal/path/xml/NodeChildrenImpl.java <==
package com.jayway.restassured.internal.path.xml;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class NodeChildrenImpl
  extends com.jayway.restassured.internal.path.xml.NodeBase  implements
    com.jayway.restassured.path.xml.element.NodeChildren {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getNodeList() { return null;}
public  void setNodeList(java.lang.Object value) { }
public  java.lang.Object getGroovyNodes() { return null;}
public  void setGroovyNodes(java.lang.Object value) { }
public  com.jayway.restassured.path.xml.element.Node get(int index) { return (com.jayway.restassured.path.xml.element.Node)null;}
public  int size() { return (int)0;}
public  boolean isEmpty() { return false;}
public  java.util.Iterator<java.lang.String> iterator() { return (java.util.Iterator<java.lang.String>)null;}
public  java.lang.Object leftShift(com.jayway.restassured.path.xml.element.Node node) { return null;}
public  java.lang.String toString() { return (java.lang.String)null;}
public  java.lang.Iterable<com.jayway.restassured.path.xml.element.Node> nodeIterable() { return (java.lang.Iterable<com.jayway.restassured.path.xml.element.Node>)null;}
public <T> T get(java.lang.String name) { return null;}
@java.lang.Override() public <T> T getPath(java.lang.String path) { return null;}
@java.lang.Override() public  java.util.Iterator<com.jayway.restassured.path.xml.element.Node> nodeIterator() { return (java.util.Iterator<com.jayway.restassured.path.xml.element.Node>)null;}
@java.lang.Override() public  java.util.List<com.jayway.restassured.path.xml.element.Node> list() { return (java.util.List<com.jayway.restassured.path.xml.element.Node>)null;}
@java.lang.Override() public <T> java.util.List<T> getList(java.lang.String name) { return (java.util.List<T>)null;}
@java.lang.Override() public  java.lang.Object getBackingGroovyObject() { return null;}
public class NodeListIterator
  extends java.lang.Object  implements
    java.util.Iterator<java.lang.String>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getIterator() { return null;}
public  void setIterator(java.lang.Object value) { }
@java.lang.Override() public  boolean hasNext() { return false;}
@java.lang.Override() public  java.lang.String next() { return (java.lang.String)null;}
@java.lang.Override() public  void remove() { }
}
}

==> xml-path-2.9.0-sources.jar: com/jayway/restassured/internal/path/xml/NodeChildrenImpl.java <==
package com.jayway.restassured.internal.path.xml;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class NodeChildrenImpl
  extends com.jayway.restassured.internal.path.xml.NodeBase  implements
    com.jayway.restassured.path.xml.element.NodeChildren {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getNodeList() { return null;}
public  void setNodeList(java.lang.Object value) { }
public  java.lang.Object getGroovyNodes() { return null;}
public  void setGroovyNodes(java.lang.Object value) { }
public  com.jayway.restassured.path.xml.element.Node get(int index) { return (com.jayway.restassured.path.xml.element.Node)null;}
public  int size() { return (int)0;}
public  boolean isEmpty() { return false;}
public  java.util.Iterator<java.lang.String> iterator() { return (java.util.Iterator)null;}
public  java.lang.Object leftShift(com.jayway.restassured.path.xml.element.Node node) { return null;}
public  java.lang.String toString() { return (java.lang.String)null;}
public  java.lang.Iterable<com.jayway.restassured.path.xml.element.Node> nodeIterable() { return (java.lang.Iterable)null;}
public <T> T get(java.lang.String name) { return null;}
@java.lang.Override() public <T> T getPath(java.lang.String path) { return null;}
@java.lang.Override() public  java.util.Iterator<com.jayway.restassured.path.xml.element.Node> nodeIterator() { return (java.util.Iterator)null;}
@java.lang.Override() public  java.util.List<com.jayway.restassured.path.xml.element.Node> list() { return (java.util.List)null;}
@java.lang.Override() public <T> java.util.List<T> getList(java.lang.String name) { return (java.util.List)null;}
@java.lang.Override() public  java.lang.Object getBackingGroovyObject() { return null;}
public class NodeListIterator
  extends java.lang.Object  implements
    java.util.Iterator<java.lang.String>,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getIterator() { return null;}
public  void setIterator(java.lang.Object value) { }
@java.lang.Override() public  boolean hasNext() { return false;}
@java.lang.Override() public  java.lang.String next() { return (java.lang.String)null;}
@java.lang.Override() public  void remove() { }
}
}
